@@ -28,3 +28,6 @@ class Contract:
             )
 
         return fn
+
+    def bytecode_ops(self):
+        bytecode = self._contract.web3.eth.get_code(self.address)
